$set 3 #Configmenu

$ #ConfigOptions
# Configurazione
$ #FocusModel
# Tipo Di Focus
$ #WindowPlacement
# Posizionamento delle finestre
$ #ImageDithering
# Dithering Delle Immagini
$ #OpaqueMove
# Movimento Delle Finestre Opaco
$ #FullMax
# Massimizzazione Completa
$ #FocusNew
# Dai Il Focus Alle Nuove Finestre
$ #FocusLast
# Dai Il Focus Alla Finestra Al Cambio di Workspace
$ #ClickToFocus
# Clicca Per Il Focus
$ #SloppyFocus
# Sloppy Focus
$ #AutoRaise
# Auto Raise
$ #SmartRows
# Posizionamento Intelligente (Righe)
$ #SmartCols
# Posizionamento Intelligente (Colonne)
$ #Cascade
# Posizionamento A Cascata
$ #LeftRight
# Da Sinistra A Destra
$ #RightLeft
# Da Destra A Sinistra
$ #TopBottom
# Da Sopra A Sotto
$ #BottomTop
# Da Sotto A Sopra
$ #Tabs
# Usa I Tabs
$ #Icons
# Usa Le Icone
$ #TabPlacement
# Posizionamento Del Tab
$ #TabRotateVertical
# Routa Verticalmente I Tab
$ #SemiSloppyFocus
# Semi Sloppy Focus
$ #MaxOverSlit
# Maximize Over Slit
$ #SloppyWindowGrouping
# Sloppy Window Grouping
$ #WorkspaceWarping
# Workspace Warping
$ #DesktopWheeling
# Desktop Wheeling
